<template>
  <div class="container" v-if="!!task.status">
    <h1 class="fs-3 fl-4">Task Usage</h1>
    <p class="fl-5" v-html="contents ['subtext']"></p>

    <div class="text-light fs-14px p-2">
      <ul class="p-0 m-0 pl-6">
        <li><span class="text-grey">Task Name:</span> {{ task.name }}</li>
        <li><span class="text-grey">Task Type:</span> {{ _TASK_TYPES [task.task_type].name }}</li>
        <li><span class="text-grey">Status:</span> <span class="badge px-0 fs-14px" :class="'text-' + statusNames [task.status].color">{{ statusNames [task.status].name }}</span></li>
        <li><span class="text-grey">Credit:</span> {{ parseInt (task.credits_used).format () }}</li>
      </ul>
    </div>

    <p class="fl-5">
      <p class="my-5">

      </p>

      <div class="mt-7 actions">
        <div class="d-flex justify-content-between">
          <div class="text-light">Total <b>{{ total }}</b> records</div>
          <div><button class="btn btn-sm btn-primary mr-4" @click="refreshList ()"><i class="bi bi-arrow-clockwise"></i> Refresh</button></div>
        </div>
      </div>

      <div class="mt-4">
        <scrollable ref="scroller" :items="items" height="400px" @scrollend="(currentPage) => pagenate (currentPage)">
          <table class="table table-sm table-dark table-hover table-striped">
            <thead>
              <tr>
                <th scope="col" class="text-end">#</th>
                <th scope="col">Date</th>
                <th scope="col">IP Address</th>
                <th scope="col">Resource</th>
                <th scope="col">Credit</th>
                <th scope="col">Image</th>
                <th scope="col">Status</th>
              </tr>
            </thead>

            <tbody v-if="items.length == 0">
              <tr>
                <td colspan="8" class="text-center py-8">No usage at this time.</td>
              </tr>
            </tbody>

            <tbody v-else class="fs-13px">
              <tr v-for="item, index in items">
                <td class="text-end">{{  index + 1  }}</td>
                <td class="text-nowrap">{{ item.in_date.dateformat ("%b %d, %Y %H:%M") }}</td>
                <td style="min-width: 100px;">{{ item.ip_address }}</td>
                <td style="min-width: 100px;">{{ item.resource }}</td>
                <td style="min-width: 60px;">{{ item.cost }}</td>
                <td style="min-width: 80px;">{{ item.image_name }}</td>
                <td style="min-width: 60px;"><span class="badge mx-0 px-0">{{ !!item.status ? item.status : 'NORMAL' }}</span></td>
              </tr>
            </tbody>
          </table>
        </scrollable>
      </div>
    </p>
  </div>
</template>





<style scoped>
.reference {
  color: #9f9f9f;
  font-size: 15px;
}
</style>






<script setup>
import Scrollable from "/atila-vue/components/scrollable.vue"
const scroller = ref (null)

const ITEM_PER_PAGE = 20
const { state } = useStore ()
const route = useRoute ()
const total = ref (0)
const items = ref ([])
const task = ref ({})
const contents = ref ({})
const statusNames = TASK_STATUS_NAME
const _TASK_TYPES = TASK_TYPES

async function pagenate (pageIndex = 0) {
  if (pageIndex == 0) {
    items.value = []
  }
  const resp = await backend.get ('GET_USAGE_LIST', {task_id: route.params.id, offset: pageIndex * ITEM_PER_PAGE, fetch: ITEM_PER_PAGE})
  total.value = resp.data.total
  for (const item of resp.data.result) {
    items.value.push (item)
  }
  scroller.value.updated (resp.data.result.length, pageIndex)
}

onBeforeMount (async () => {
  contents.value = await frontend.fetch_contents ({}, '/tasks/:id')
})

async function refreshList () {
  const resp = await backend.get ('GET_DELETE_TASK', {task_id: route.params.id})
  task.value = resp.data
  pagenate (0)
}

onMounted (() => {
  frontend.set_title ()
  refreshList ()
})

watch (() => route.params, (newVal, oldVal) => {
  if (!newVal.id) return
  if (newVal.id == task.value.id) return
  refreshList ()
})

</script>

<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.required (['user'], {path: '/members/signin'}, {to, from, next})
  }
}
</script>
